==> instancio-core-4.4.0.jar: META-INF/versions/9/module-info.java <==
module org.instancio.core {
    requires org.slf4j;
    /* static phase */ requires jakarta.persistence;
    /* static phase */ requires jakarta.validation;
    /* static phase */ requires java.persistence;
    /* static phase */ requires java.validation;
    /* static phase */ requires java.sql;
    /* static phase */ requires java.xml;
    /* static phase */ requires jdk.unsupported;
    /* static phase */ requires org.jetbrains.annotations;
    /* static phase */ requires org.hibernate.validator;

    exports org.instancio;
    exports org.instancio.documentation;
    exports org.instancio.exception;
    exports org.instancio.generator;
    exports org.instancio.generator.hints;
    exports org.instancio.generator.specs;
    exports org.instancio.generator.specs.can;
    exports org.instancio.generator.specs.pol;
    exports org.instancio.generator.specs.usa;
    exports org.instancio.generators;
    exports org.instancio.generators.can;
    exports org.instancio.generators.pol;
    exports org.instancio.generators.usa;
    exports org.instancio.settings;
    exports org.instancio.spi;
    exports org.instancio.internal to org.instancio.guava;
    exports org.instancio.internal.generator to org.instancio.guava;
    exports org.instancio.internal.generator.domain.internet to org.instancio.guava;
    exports org.instancio.internal.generator.util to org.instancio.guava;
    exports org.instancio.internal.spi to org.instancio.guava;
    exports org.instancio.support to org.instancio.junit;
    exports org.instancio.internal.util to org.instancio.guava, org.instancio.junit, org.instancio.quickcheck, org.instancio.test.contract;

}

==> instancio-core-4.7.0.jar: META-INF/versions/9/module-info.java <==
module org.instancio.core {
    requires org.slf4j;
    /* static phase */ requires jakarta.persistence;
    /* static phase */ requires jakarta.validation;
    /* static phase */ requires java.persistence;
    /* static phase */ requires java.validation;
    /* static phase */ requires java.sql;
    /* static phase */ requires java.xml;
    /* static phase */ requires jdk.unsupported;
    /* static phase */ requires org.jetbrains.annotations;
    /* static phase */ requires org.hibernate.validator;

    exports org.instancio;
    exports org.instancio.documentation;
    exports org.instancio.exception;
    exports org.instancio.generator;
    exports org.instancio.generator.hints;
    exports org.instancio.generator.specs;
    exports org.instancio.generator.specs.can;
    exports org.instancio.generator.specs.pol;
    exports org.instancio.generator.specs.usa;
    exports org.instancio.generators;
    exports org.instancio.generators.can;
    exports org.instancio.generators.pol;
    exports org.instancio.generators.usa;
    exports org.instancio.settings;
    exports org.instancio.spi;
    exports org.instancio.internal to org.instancio.guava;
    exports org.instancio.internal.generator to org.instancio.guava;
    exports org.instancio.internal.generator.domain.internet to org.instancio.guava;
    exports org.instancio.internal.generator.util to org.instancio.guava;
    exports org.instancio.internal.spi to org.instancio.guava;
    exports org.instancio.internal.util to org.instancio.guava, org.instancio.junit, org.instancio.quickcheck;
    exports org.instancio.support to org.instancio.junit;

}
